@@ -175,11 +175,11 @@ DocumentHolder::DocumentHolder( const uno::Reference< lang::XMultiServiceFactory
     m_aOutplaceFrameProps.realloc( 3 );
     beans::NamedValue aArg;
 
-    aArg.Name = ::rtl::OUString::createFromAscii("TopWindow");
+    aArg.Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("TopWindow"));
     aArg.Value <<= sal_True;
     m_aOutplaceFrameProps[0] <<= aArg;
 
-    aArg.Name = ::rtl::OUString::createFromAscii("MakeVisible");
+    aArg.Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("MakeVisible"));
     aArg.Value <<= sal_False;
     m_aOutplaceFrameProps[1] <<= aArg;
 
@@ -197,7 +197,7 @@ DocumentHolder::DocumentHolder( const uno::Reference< lang::XMultiServiceFactory
         }
         m_refCount--;
 
-        aArg.Name = ::rtl::OUString::createFromAscii("ParentFrame");
+        aArg.Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ParentFrame"));
         aArg.Value <<= xDesktop; //TODO/LATER: should use parent document frame
         m_aOutplaceFrameProps[2] <<= aArg;
     }
@@ -433,7 +433,7 @@ sal_Bool DocumentHolder::ShowInplace( const uno::Reference< awt::XWindowPeer >&
 
             uno::Reference< embed::XHatchWindowFactory > xHatchFactory(
                     m_xFactory->createInstance(
-                        ::rtl::OUString::createFromAscii( "com.sun.star.embed.HatchWindowFactory" ) ),
+                        ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.embed.HatchWindowFactory" )) ),
                     uno::UNO_QUERY );
 
             if ( !xHatchFactory.is() )
@@ -468,7 +468,7 @@ sal_Bool DocumentHolder::ShowInplace( const uno::Reference< awt::XWindowPeer >&
                                                 awt::WindowAttribute::SHOW | awt::VclWindowPeerAttribute::CLIPCHILDREN );
 
         uno::Reference< awt::XToolkit > xToolkit(
-                            m_xFactory->createInstance( ::rtl::OUString::createFromAscii( "com.sun.star.awt.Toolkit" ) ),
+                            m_xFactory->createInstance( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.awt.Toolkit" )) ),
                             uno::UNO_QUERY );
         if ( !xToolkit.is() )
             throw uno::RuntimeException();
@@ -480,20 +480,20 @@ sal_Bool DocumentHolder::ShowInplace( const uno::Reference< awt::XWindowPeer >&
 
         // create a frame based on the specified window
         uno::Reference< lang::XSingleServiceFactory > xFrameFact(
-            m_xFactory->createInstance( ::rtl::OUString::createFromAscii( "com.sun.star.frame.TaskCreator" ) ),
+            m_xFactory->createInstance( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.frame.TaskCreator" )) ),
             uno::UNO_QUERY_THROW );
 
         uno::Sequence< uno::Any > aArgs( 2 );
         beans::NamedValue aArg;
 
-        aArg.Name    = ::rtl::OUString::createFromAscii("ContainerWindow");
+        aArg.Name    = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ContainerWindow"));
         aArg.Value <<= xOwnWindow;
         aArgs[0] <<= aArg;
 
         uno::Reference< frame::XFrame > xContFrame( xContDisp, uno::UNO_QUERY );
         if ( xContFrame.is() )
         {
-            aArg.Name    = ::rtl::OUString::createFromAscii("ParentFrame");
+            aArg.Name    = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ParentFrame"));
             aArg.Value <<= xContFrame;
             aArgs[1] <<= aArg;
         }
@@ -508,7 +508,7 @@ sal_Bool DocumentHolder::ShowInplace( const uno::Reference< awt::XWindowPeer >&
 
         if ( !SetFrameLMVisibility( m_xFrame, sal_False ) )
         {
-            OSL_ENSURE( sal_False, "Can't deactivate LayoutManager!\n" );
+            OSL_FAIL( "Can't deactivate LayoutManager!\n" );
             // TODO/LATER: error handling?
         }
 
@@ -620,7 +620,7 @@ void DocumentHolder::FindConnectPoints(
         xMenu->getByIndex( nInd ) >>= aProps;
         rtl::OUString aCommand;
         for ( sal_Int32 nSeqInd = 0; nSeqInd < aProps.getLength(); nSeqInd++ )
-            if ( aProps[nSeqInd].Name.equalsAscii( "CommandURL" ) )
+            if ( aProps[nSeqInd].Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "CommandURL" ) ) )
             {
                 aProps[nSeqInd].Value >>= aCommand;
                 break;
@@ -629,9 +629,9 @@ void DocumentHolder::FindConnectPoints(
         if ( !aCommand.getLength() )
             throw uno::RuntimeException();
 
-        if ( aCommand.equalsAscii( ".uno:PickList" ) )
+        if ( aCommand.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ".uno:PickList" ) ) )
             nConnectPoints[0] = nInd;
-        else if ( aCommand.equalsAscii( ".uno:WindowList" ) )
+        else if ( aCommand.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ".uno:WindowList" ) ) )
             nConnectPoints[1] = nInd;
     }
 }
@@ -871,7 +871,7 @@ uno::Reference< frame::XFrame > DocumentHolder::GetDocFrame()
     if ( !m_xFrame.is() )
     {
         uno::Reference< lang::XSingleServiceFactory > xFrameFact(
-            m_xFactory->createInstance( ::rtl::OUString::createFromAscii( "com.sun.star.frame.TaskCreator" ) ),
+            m_xFactory->createInstance( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.frame.TaskCreator" ) )),
             uno::UNO_QUERY_THROW );
 
         m_xFrame.set(xFrameFact->createInstanceWithArguments( m_aOutplaceFrameProps ), uno::UNO_QUERY_THROW);
@@ -1033,13 +1033,13 @@ sal_Bool DocumentHolder::LoadDocToFrame( sal_Bool bInPlace )
                 sUrl = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(".component:DB/ReportDesign"));
             }
             else if( xServiceInfo.is() 
-                &&   xServiceInfo->supportsService( ::rtl::OUString::createFromAscii("com.sun.star.chart2.ChartDocument")) )
+                &&   xServiceInfo->supportsService( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.chart2.ChartDocument")) ))
                 sUrl = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("private:factory/schart"));
             else
                 sUrl = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("private:object"));
 
             xComponentLoader->loadComponentFromURL( sUrl,
-                                                        rtl::OUString::createFromAscii( "_self" ),
+                                                        rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "_self" )),
                                                         0,
                                                         aArgs.getPropertyValues() );
 
@@ -1239,11 +1239,11 @@ void SAL_CALL DocumentHolder::notifyEvent( const document::EventObject& Event )
     if( m_pEmbedObj && Event.Source == m_xComponent )
     {
         // for now the ignored events are not forwarded, but sent by the object itself
-        if ( !Event.EventName.equalsAscii( "OnSave" )
-          && !Event.EventName.equalsAscii( "OnSaveDone" )
-          && !Event.EventName.equalsAscii( "OnSaveAs" )
-          && !Event.EventName.equalsAscii( "OnSaveAsDone" )
-          && !( Event.EventName.equalsAscii( "OnVisAreaChanged" ) && m_nNoResizeReact ) )
+        if ( !Event.EventName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "OnSave" ) )
+          && !Event.EventName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "OnSaveDone" ) )
+          && !Event.EventName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "OnSaveAs" ) )
+          && !Event.EventName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "OnSaveAsDone" ) )
+          && !( Event.EventName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "OnVisAreaChanged" ) ) && m_nNoResizeReact ) )
             m_pEmbedObj->PostEvent_Impl( Event.EventName, Event.Source );
     }
 }
