@@ -122,19 +122,30 @@ SdrRectObj::SdrRectObj(SdrObjKind eNewTextKind, const Rectangle& rNewRect, SvStr
 
 SdrRectObj::~SdrRectObj()
 {
-    if(mpXPoly) 
-    {
-        delete mpXPoly;
-    }
+    delete mpXPoly;
+}
+
+SdrRectObj& SdrRectObj::operator=(const SdrRectObj& rCopy)
+{
+    if ( this == &rCopy )
+        return *this;
+
+    SdrTextObj::operator=( rCopy );
+
+    delete mpXPoly;
+
+    if ( rCopy.mpXPoly )
+        mpXPoly = new XPolygon( *rCopy.mpXPoly );
+    else
+        mpXPoly = NULL;
+
+    return *this;
 }
 
 void SdrRectObj::SetXPolyDirty()
 {
-    if(mpXPoly) 
-    {
-        delete mpXPoly;
-        mpXPoly = 0L;
-    }
+    delete mpXPoly;
+    mpXPoly = 0L;
 }
 
 bool SdrRectObj::PaintNeedsXPoly(long nEckRad) const
@@ -169,6 +180,7 @@ XPolygon SdrRectObj::ImpCalcXPoly(const Rectangle& rRect1, long nRad1) const
 
 void SdrRectObj::RecalcXPoly()
 {
+    delete mpXPoly;
     mpXPoly = new XPolygon(ImpCalcXPoly(aRect,GetEckenradius()));
 }
 
