@@ -332,6 +332,7 @@ void SdrTableObjImpl::operator=( const SdrTableObjImpl& rSource )
 void SdrTableObjImpl::SetModel(SdrModel* /*pOldModel*/, SdrModel* pNewModel)
 {
     // try to find new table style
+    disconnectTableStyle();
 
     Reference< XIndexAccess > xNewTableStyle;
     if( mxTableStyle.is() ) try
@@ -362,6 +363,7 @@ void SdrTableObjImpl::SetModel(SdrModel* /*pOldModel*/, SdrModel* pNewModel)
 
     mxTableStyle = xNewTableStyle;
 
+    connectTableStyle();
     update();
 }
 
